EXPORTS
	__5RSADB @ 1 NONAME R3UNUSED ; RSADB::RSADB(void)
	BytesUnparsed__13TPfkeyRecvMsg @ 2 NONAME R3UNUSED ; TPfkeyRecvMsg::BytesUnparsed(void)
	CancelRecv__5RSADB @ 3 NONAME R3UNUSED ; RSADB::CancelRecv(void)
	Close__5RSADB @ 4 NONAME R3UNUSED ; RSADB::Close(void)
	FinalizeAndSend__5RSADBR17TPfkeySendMsgBaseR14TRequestStatus @ 5 NONAME R3UNUSED ; RSADB::FinalizeAndSend(TPfkeySendMsgBase &, TRequestStatus &)
	Finalize__17TPfkeySendMsgBase @ 6 NONAME R3UNUSED ; TPfkeySendMsgBase::Finalize(void)
	NextExtension__13TPfkeyRecvMsgR12TPfkeyAnyExt @ 7 NONAME R3UNUSED ; TPfkeyRecvMsg::NextExtension(TPfkeyAnyExt &)
	Open__5RSADBR11RSocketServ @ 8 NONAME R3UNUSED ; RSADB::Open(RSocketServ &)
	ReadRequest__5RSADBR5TDes8R14TRequestStatus @ 9 NONAME R3UNUSED ; RSADB::ReadRequest(TDes8 &, TRequestStatus &)
	Reset__13TPfkeyRecvMsg @ 10 NONAME R3UNUSED ; TPfkeyRecvMsg::Reset(void)
	Reset__17TPfkeySendMsgBaseUcUcii @ 11 NONAME ; TPfkeySendMsgBase::Reset(unsigned char, unsigned char, int, int)
	SendRequest__5RSADBRC6TDesC8R14TRequestStatus @ 12 NONAME R3UNUSED ; RSADB::SendRequest(TDesC8 const &, TRequestStatus &)
	"_._5RSADB" @ 13 NONAME R3UNUSED ; RSADB::~RSADB(void)
	__11TPfkeyExtSAUlUcUcUcUcUl @ 14 NONAME ; TPfkeyExtSA::TPfkeyExtSA(unsigned long, unsigned char, unsigned char, unsigned char, unsigned char, unsigned long)
	__12TPfkeyExtKeyRC6TDesC8UsUc @ 15 NONAME ; TPfkeyExtKey::TPfkeyExtKey(TDesC8 const &, unsigned short, unsigned char)
	__13TPfkeyRecvMsg @ 16 NONAME R3UNUSED ; TPfkeyRecvMsg::TPfkeyRecvMsg(void)
	__13TPfkeyRecvMsgRC6TDesC8 @ 17 NONAME R3UNUSED ; TPfkeyRecvMsg::TPfkeyRecvMsg(TDesC8 const &)
	__14TPfkeyExtIdentRC6TDesC8UsUs @ 18 NONAME ; TPfkeyExtIdent::TPfkeyExtIdent(TDesC8 const &, unsigned short, unsigned short)
	__16TPfkeyExtAddressRC9TInetAddrUcUcUc @ 19 NONAME ; TPfkeyExtAddress::TPfkeyExtAddress(TInetAddr const &, unsigned char, unsigned char, unsigned char)
	__16TPfkeyExtPrivateRC6TDesC8 @ 20 NONAME R3UNUSED ; TPfkeyExtPrivate::TPfkeyExtPrivate(TDesC8 const &)
	__17TPfkeyExtLifetimeUlRC6TInt64N22RCUs @ 21 NONAME ; TPfkeyExtLifetime::TPfkeyExtLifetime(unsigned long, TInt64 const &, TInt64 const &, TInt64 const &, unsigned short const &)
	__17TPfkeyExtSpirangeUlUl @ 22 NONAME R3UNUSED ; TPfkeyExtSpirange::TPfkeyExtSpirange(unsigned long, unsigned long)
	__17TPfkeySendMsgBase @ 23 NONAME R3UNUSED ; TPfkeySendMsgBase::TPfkeySendMsgBase(void)
	__17TPfkeySendMsgBaseUcUcii @ 24 NONAME ; TPfkeySendMsgBase::TPfkeySendMsgBase(unsigned char, unsigned char, int, int)
	AddExt__17TPfkeySendMsgBaseRC12TPfkeyAnyExtRC6TDesC8 @ 25 NONAME R3UNUSED ; TPfkeySendMsgBase::AddExt(TPfkeyAnyExt const &, TDesC8 const &)
	CancelSend__5RSADB @ 26 NONAME R3UNUSED ; RSADB::CancelSend(void)

